==> haskell-ipynb-0.1-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-7es6ATEkgPFRfCh17tqm5
key: ipynb-0.1-7es6ATEkgPFRfCh17tqm5
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: ebefa37c144bf132a35f1e3f2ecd9312
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-7es6ATEkgPFRfCh17tqm5
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-IyzpR8ZKM01cdu4CqCAh6
key: ipynb-0.1-IyzpR8ZKM01cdu4CqCAh6
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: aa8c8e6598c14a3e9a4b1ec304eb8107
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-IyzpR8ZKM01cdu4CqCAh6
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
